interceptify library

Classes

Interceptify
Main API for Interceptify network interceptor
InterceptifyChopperInterceptor
Chopper interceptor for capturing, pausing, and inspecting network requests made via the package:chopper library.
InterceptifyChopperRequest
Custom request implementation to bypass Chopper's interceptor chain body modification assertions in debug mode.
InterceptifyChopperResponse<BodyType>
Custom response implementation to bypass Chopper's interceptor chain body modification assertions in debug mode.
InterceptifyHttpClient
HTTP client interceptor for capturing, pausing, and inspecting network requests made via the package:http library.